@@ -10,6 +10,9 @@ OC.L10N.register(
     "Open »%s«" : "فتح »%s«",
     "Cheers!" : "تحياتي!",
     "Upcoming events" : "الفعاليات القادمة",
+    "Appointments" : "المواعيد",
+    "Confirm" : "تأكيد",
+    "Date:" : "التاريخ:",
     "Calendar" : "التقويم",
     "A Calendar app for Nextcloud" : "تطبيق التقويم لـ نكست كلاود",
     "Previous day" : "اليوم الماضي",
@@ -18,11 +21,15 @@ OC.L10N.register(
     "Next day" : "اليوم القادم",
     "Next week" : "الاسبوع القادم",
     "Next month" : "الشهر القادم",
+    "New event" : "حدث جديد",
     "Today" : "اليوم",
     "Day" : "يوم",
     "Week" : "أسبوع",
     "Month" : "شهر",
     "List" : "قائمة",
+    "Preview" : "معاينة",
+    "Copy link" : "انسخ الرابط",
+    "Edit" : "تعديل",
     "Delete" : "حذف ",
     "Untitled calendar" : "تقويم بدون اسم",
     "Edit name" : "تعديل الاسم",
@@ -30,6 +37,7 @@ OC.L10N.register(
     "Edit color" : "تعديل اللون",
     "Saving color …" : "جاري حفظ اللون    …",
     "Copy private link" : "نسخ الرابط الخاص",
+    "Export" : "تصدير",
     "Unshare from me" : "أنت ألغيت المشاركة",
     "An error occurred, unable to change visibility of the calendar." : "حدث خطأ، لا يمكن تعديل وضعية ظهور التقويم.",
     "An error occurred, unable to delete the calendar." : "حدث خطأ، لا يمكن حذف التقويم.",
@@ -73,6 +81,11 @@ OC.L10N.register(
     "Creating subscription …" : "جاري انشاء اشتراك  …",
     "An error occurred, unable to create the calendar." : "حدث خطأ، لا يمكن انشاء التقويم.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "يرجى ادخال رابط صحيح (يبدأ بـ https://, http://, webcals://, webcal://)",
+    "Name" : "الاسم",
+    "Deleted" : "تم حذفه",
+    "Restore" : "استعادة ",
+    "Delete permanently" : "حذف بشكل دائم",
+    "Empty trash bin" : "تفريغ سلة المهملات",
     "Could not update calendar order." : "لا يمكن تحديث ترتيب التقويم.",
     "Import calendars" : "استيراد التقويم",
     "Please select a calendar to import into …" : "يرجى اختيار تقويم للاستيراد اليه  …",
@@ -92,6 +105,7 @@ OC.L10N.register(
     "Day view" : "مشاهدات يومية",
     "Week view" : "مشاهدات اسبوعية",
     "Month view" : "مشاهدات شهرية",
+    "List view" : "عرض على شكل قائمة",
     "Actions" : "الإجراءات",
     "Create event" : "انشاء فعالية",
     "Show shortcuts" : "انشاء اختصارات",
@@ -105,13 +119,24 @@ OC.L10N.register(
     "Copy iOS/macOS CalDAV address" : "نسخ عنوان CalDAV لأجهزة الماك/الأيفون",
     "Show keyboard shortcuts" : "اظهار اختصارات لوحة المفاتيح",
     "Settings & import" : "الإعدادات و الإستيراد",
+    "No reminder" : "لا يوجد تذكير ",
     "CalDAV link copied to clipboard." : "تم نسخ CalDAV.",
     "CalDAV link could not be copied to clipboard." : "لا يمكن نسخ CalDAV.",
     "Location" : "الموقع",
     "Description" : "الوصف",
+    "Duration" : "المدة الزمنية",
+    "to" : "إلى",
+    "Add" : "إضافة",
     "Monday" : "الإثنين",
+    "Tuesday" : "الثلاثاء",
+    "Wednesday" : "الأربعاء",
+    "Thursday" : "الخميس",
+    "Friday" : "الجمعة",
+    "Saturday" : "السبت",
+    "Sunday" : "الأحد",
     "Save" : "حفظ",
     "Update" : "حدث",
+    "Your email address" : "عنوان بريديك الإلكتروني",
     "before at" : "قبل",
     "Notification" : "تنبيه",
     "Email" : "البريد الإلكتروني",
@@ -126,18 +151,23 @@ OC.L10N.register(
     "at" : "في",
     "+ Add reminder" : "+ اضافة تذكير",
     "_second_::_seconds_" : ["ثانية","ثانية","ثانية","ثواني","ثواني","ثواني"],
+    "Available" : "متوفر",
+    "Not available" : "غير متوفر",
     "Availability of attendees, resources and rooms" : "متوفرين من الحضور والموارد والغرف",
     "Free" : "متوفر",
     "Busy (tentative)" : "مشغول (حاليا)",
     "Busy" : "مشغول",
     "Out of office" : "خارج المكتب",
     "Unknown" : "غير معروف",
+    "Accept" : "قبول",
+    "Decline" : "رفض",
     "Tentative" : "مؤقت",
     "Create Talk room for this event" : "انشاء غرفة تحدث لهذه الفعالية.",
     "Show busy times" : "اظهار الاوقات الممتلئة",
     "No attendees yet" : "لا يوجد حضور بعد",
     "Successfully appended link to talk room to description." : "تم اضافة الرابط في وصف غرفة التحدث بنجاح.",
     "Error creating Talk room" : "خطأ في انشاء غرفة تحدث",
+    "Send email" : "إرسال بريد",
     "Chairperson" : "الرئيس",
     "Required participant" : "مشارك مطلوب",
     "Optional participant" : "مشارك اختياري",
@@ -205,7 +235,6 @@ OC.L10N.register(
     "Close" : "إغلاق",
     "Show more details" : "اظهار المزيد من التفاصيل",
     "Subscribe to {name}" : "اشتراك مع {name}",
-    "Download {name}" : "تحميل {name}",
     "Anniversary" : "ذكرى سنوية",
     "Appointment" : "موعد",
     "Business" : "عمل",
@@ -243,12 +272,14 @@ OC.L10N.register(
     "Untitled event" : "فعالية بدون اسم",
     "Untitled task" : "مهمة بدون اسم",
     "Please ask your administrator to enable the Tasks App." : "تواصل مع مسؤول النظام لاستخدام تطبيق المهام.",
+    "Next" : "التالي",
     "%n more" : "%n المزيد",
     "No events to display" : "لا يوجد فعاليات",
     "No events" : "لا يوجد فعاليات",
     "Create a new event or change the visible time-range" : "اصنع فعالية جديدة أو قم بتغيير عامل الوقت",
     "It might have been deleted, or there was a typo in a link" : "لربما انحذفت، أو الحروف غير مطابقة في الرابط",
     "It might have been deleted, or there was a typo in the link" : "لربما انحذفت، أو الحروف غير مطابقة في الرابط",
+    "Other" : "آخر",
     "When shared show" : "عندما تظهر المشاركة",
     "When shared show full event" : "عرض الفعالية كاملة عند مشاركته",
     "When shared show only busy" : "عرض الازدحام عند مشاركة الفعالية",
@@ -273,7 +304,9 @@ OC.L10N.register(
     "Meditation" : "تفكير",
     "Relaxing" : "لحظة راحة",
     "Relax" : "راحة",
+    "Commuting" : "تجوال",
     "Presentation" : "عرض تقديمي",
+    "Talk" : "التحدث",
     "Camping" : "تخيم",
     "Camp" : "مخيم",
     "Movie" : "فلم",
@@ -310,6 +343,7 @@ OC.L10N.register(
     "Doctor" : "دكتور",
     "Health" : "صحة",
     "Dentist" : "طبيب أسنان",
+    "Hospital" : "مستشفى",
     "Interview" : "مقابلة",
     "Training" : "تدريب",
     "Practice" : "ممارسة",
@@ -348,12 +382,14 @@ OC.L10N.register(
     "Party" : "حفله",
     "Celebration" : "احتفال",
     "Celebrate" : "احتفال",
+    "Birthday" : "عيد ميلاد",
     "Shopping" : "تسوق",
     "Skate" : "تزلج",
     "Skateboard" : "لوح تزلج",
     "Wine tasting" : "تذوق",
     "Golf" : "الجولف",
     "Dinner" : "عشاء",
-    "Lunch" : "غداء"
+    "Lunch" : "غداء",
+    "User not found" : "لم يتم العثور على المستخدم"
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
