@@ -119,6 +119,7 @@ OC.L10N.register(
     "Actions" : "Accions",
     "Create event" : "Crea un esdeveniment",
     "Show shortcuts" : "Mostra les dreceres",
+    "Editor" : "Editor",
     "Enable birthday calendar" : "Activa el calendari d'aniversaris",
     "Show tasks in calendar" : "Mostra les tasques en el calendari",
     "Enable simplified editor" : "Habilita l'editor simplificat",
@@ -347,6 +348,7 @@ OC.L10N.register(
     "Relaxing" : "Relax",
     "Relax" : "Relax",
     "Commuting" : "Trajecte",
+    "Invoice" : "Factura",
     "Presentation" : "Presentació",
     "Talk" : "Parla",
     "Camping" : "Acampada",
