@@ -3,16 +3,26 @@ OC.L10N.register(
     {
     "Hello," : "Salute %s,",
     "Cheers!" : "Congratulationes!",
+    "Confirm" : "Confirmar",
     "Calendar" : "Calendario",
+    "New event" : "Nove evento",
     "Today" : "Hodie",
     "Day" : "Die",
     "Week" : "Septimana",
     "Month" : "Mense",
+    "Preview" : "Previsualisar",
+    "Copy link" : "Copiar ligamine",
+    "Edit" : "Modificar",
     "Delete" : "Deler",
+    "Export" : "Exportar",
     "Share link" : "Compartir ligamine",
     "Share with users or groups" : "Compartir con usatores o gruppos",
     "can edit" : "pote modificar",
     "New calendar" : "Nove calendario",
+    "Name" : "Nomine",
+    "Deleted" : "Delite",
+    "Restore" : "Restaurar",
+    "Delete permanently" : "Deler permanentemente",
     "Cancel" : "Cancellar",
     "Automatic" : "Automatic",
     "Actions" : "Actiones",
@@ -20,12 +30,24 @@ OC.L10N.register(
     "Settings & import" : "Configurationes e importation",
     "Location" : "Loco",
     "Description" : "Description",
+    "to" : "a",
+    "Add" : "Adder",
     "Monday" : "Lunedi",
+    "Tuesday" : "Martedi",
+    "Wednesday" : "Mercuridi",
+    "Thursday" : "Jovedi",
+    "Friday" : "Venerdi",
+    "Saturday" : "Sabbato",
+    "Sunday" : "Dominica",
     "Save" : "Salveguardar",
     "Update" : "Actualisar",
+    "Your email address" : "Tu adresse de e-posta",
     "Email" : "E-posta",
     "Unknown" : "Incognite",
+    "Accept" : "Acceptar",
+    "Decline" : "Refusar",
     "Tentative" : "Tentative",
+    "Send email" : "Inviar message de e-posta",
     "Repeat" : "Repeter",
     "never" : "nunquam",
     "after" : "post",
@@ -39,11 +61,14 @@ OC.L10N.register(
     "Week {number} of {year}" : "Septimana {number} de {year}",
     "Daily" : "Cata die",
     "Weekly" : "Cata septimana",
+    "Next" : "Sequente",
+    "Other" : "Altere",
     "When shared show full event" : "Quando compartite, monstrar evento integremente",
     "When shared show only busy" : "Quando compartite, monstrar solo si illo es occupate",
     "When shared hide this event" : "Quando compartite, celar iste evento",
     "Confirmed" : "Confirmate",
     "Presentation" : "Presentation",
-    "Mail" : "Posta"
+    "Mail" : "Posta",
+    "Birthday" : "Anniversario de nativitate"
 },
 "nplurals=2; plural=(n != 1);");
