@@ -11,6 +11,10 @@ OC.L10N.register(
     "Open »%s«" : "Отвори »%s«",
     "Cheers!" : "Поздрав!",
     "Upcoming events" : "Престојни настани",
+    "Confirm" : "Потврди",
+    "Date:" : "Датум:",
+    "Where:" : "Каде: ",
+    "Description:" : "Опис:",
     "Calendar" : "Календар",
     "A Calendar app for Nextcloud" : "Календар апликација за Nextcloud",
     "Previous day" : "Предходен ден",
@@ -19,11 +23,15 @@ OC.L10N.register(
     "Next day" : "Следен ден",
     "Next week" : "Следна недела",
     "Next month" : "Следен месец",
+    "New event" : "Нов настан",
     "Today" : "Денес",
     "Day" : "Ден",
     "Week" : "Недела",
     "Month" : "Месец",
     "List" : "Лист",
+    "Preview" : "Преглед",
+    "Copy link" : "Копирај линк",
+    "Edit" : "Уреди",
     "Delete" : "Избриши",
     "Untitled calendar" : "Неименуван календар",
     "Edit name" : "Уреди име",
@@ -31,6 +39,7 @@ OC.L10N.register(
     "Edit color" : "Уреди бои",
     "Saving color …" : "Зачувување боја …",
     "Copy private link" : "Копирај приватен линк",
+    "Export" : "Извези",
     "Unshare from me" : "Не споделувај со мене",
     "An error occurred, unable to change visibility of the calendar." : "Настана грешка, неможе да се промени видливоста на календарот.",
     "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
@@ -80,6 +89,7 @@ OC.L10N.register(
     "Deleted" : "Избришани",
     "Restore" : "Врати",
     "Delete permanently" : "Избриши",
+    "Empty trash bin" : "Испразни ја корпата со отпадоци",
     "Could not update calendar order." : "Неможе да се ажурира редоследот на календарите.",
     "Import calendars" : "Увези календари",
     "Please select a calendar to import into …" : "Изберете календар за да направите увоз во него …",
@@ -123,9 +133,20 @@ OC.L10N.register(
     "CalDAV link could not be copied to clipboard." : "CalDAV линкот неможе да биде копиран.",
     "Location" : "Локација",
     "Description" : "Опис",
+    "Duration" : "Времетраење",
+    "to" : "до",
+    "Delete slot" : "Избриши слот",
+    "Add" : "Додади",
     "Monday" : "Понеделник",
+    "Tuesday" : "Вторник",
+    "Wednesday" : "Среда",
+    "Thursday" : "Четврток",
+    "Friday" : "Петок",
+    "Saturday" : "Сабота",
+    "Sunday" : "Недела",
     "Save" : "Зачувај",
     "Update" : "Ажурирај",
+    "Your email address" : "Вашата адреса за е-пошта",
     "before at" : "пред",
     "Notification" : "Известување",
     "Email" : "Е-пошта",
@@ -139,20 +160,13 @@ OC.L10N.register(
     "on" : "во",
     "at" : "во",
     "+ Add reminder" : "+ Додади потсетник",
+    "Add reminder" : "Додади потсетник",
     "_second_::_seconds_" : ["секунда","секунди"],
     "_minute_::_minutes_" : ["минута","минути"],
     "_hour_::_hours_" : ["час","часа"],
     "_day_::_days_" : ["ден","дена"],
     "_week_::_weeks_" : ["недела","недели"],
-    "Available." : "Достапно.",
-    "Not available." : "Недостапно.",
-    "Checking availability." : "Проверување на достапност.",
-    "Invitation accepted." : "Поканата е прифатена",
-    "Accepted {organizerName}'s invitation." : "Прифатена е покана од {organizerName}.",
-    "Invitation declined." : "Поканата е одбиена.",
-    "Declined {organizerName}'s invitation." : "Одбиена е покана од {organizerName}.",
-    "Invitation sent." : "Испратена е покана.",
-    "Has not responded to {organizerName}'s invitation yet." : "Нема одговор на поканата од {organizerName}.",
+    "Available" : "Достапно",
     "Availability of attendees, resources and rooms" : "Достапност на присутните, ресурси и соби",
     "{organizer} (organizer)" : "{organizer} (organizer)",
     "Free" : "Слободен",
@@ -160,6 +174,8 @@ OC.L10N.register(
     "Busy" : "Зафатен",
     "Out of office" : "Надвор од канцеларија",
     "Unknown" : "Непознат",
+    "Accept" : "Прифати",
+    "Decline" : "Одбиј",
     "Tentative" : "Пробно",
     "Create Talk room for this event" : "Креирај соба за разговор за овој настан",
     "Show busy times" : "Прикажи ги зафатените термини",
@@ -222,6 +238,7 @@ OC.L10N.register(
     "Please enter a valid date and time" : "Внесете валиден датум и време",
     "Type to search time zone" : "Пребарај временски зони",
     "Global" : "Глобално",
+    "Time:" : "Време:",
     "Personal" : "Лично",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Автоматското откривање на временската зона утврди дека вашата временска зона е UTC.\nОва е најверојатно резултат на безбедносните мерки на вашиот веб прелистувач\nПоставете ја вашата временска зона во подесувањата за календарот.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Вашата временска зона ({timezoneId}) не е пронајдена. Поставена е  (Координирано универзално време) UTC.\nПоставете ја вашата временска зона во подесувањата за календарот или пријавете го овој проблем.",
@@ -241,7 +258,6 @@ OC.L10N.register(
     "Close" : "Затвори",
     "Show more details" : "Прикажи повеќе детали",
     "Subscribe to {name}" : "Претплатете се на {name}",
-    "Download {name}" : "Преземи {name}",
     "Anniversary" : "Годишнина",
     "Appointment" : "Назначување",
     "Business" : "Бизнис",
@@ -301,6 +317,7 @@ OC.L10N.register(
     "Create a new event or change the visible time-range" : "Креирајте нов настан или променете го видливиот временски опсег",
     "It might have been deleted, or there was a typo in a link" : "Можеби е избришан или има грешка во врската",
     "It might have been deleted, or there was a typo in the link" : "Можеби е избришан или има грешка во врската",
+    "Other" : "Останато",
     "When shared show" : "Приказ кога е споделен",
     "When shared show full event" : "Кога е споделен, прикажи го целосно настанот",
     "When shared show only busy" : "Кога е споделен, прикажи зафатено",
@@ -324,7 +341,10 @@ OC.L10N.register(
     "Meditation" : "Медитација",
     "Relaxing" : "Релаксирање",
     "Relax" : "Опуштање",
+    "Commuting" : "На пат",
+    "Invoice" : "Фактура",
     "Presentation" : "Презентација",
+    "Talk" : "Разговор",
     "Camping" : "Кампување",
     "Camp" : "Камп",
     "Movie" : "Филм",
@@ -359,6 +379,7 @@ OC.L10N.register(
     "Doctor" : "Доктор",
     "Health" : "Здравје",
     "Dentist" : "Заболекар",
+    "Hospital" : "Болница",
     "Interview" : "Интервју",
     "Training" : "Тренинг",
     "Practice" : "Пракса",
@@ -397,12 +418,14 @@ OC.L10N.register(
     "Party" : "Забава",
     "Celebration" : "Прослава",
     "Celebrate" : "Прослава",
+    "Birthday" : "Роденден",
     "Shopping" : "Купување",
     "Skate" : "Скејтбординг",
     "Skateboard" : "Скејтбординг",
     "Wine tasting" : "Дегустација на вино",
     "Golf" : "Голф",
     "Dinner" : "Вечера",
-    "Lunch" : "Ручек"
+    "Lunch" : "Ручек",
+    "User not found" : "Корисникот не е пронајден"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
