@@ -6,6 +6,7 @@ OC.L10N.register(
     "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
     "Open »%s«" : "Hap »%s«",
     "Cheers!" : "Gëzuar!",
+    "Appointments" : "Takime",
     "Confirm" : "Konfirmo",
     "Where:" : "Ku:",
     "Description:" : "Përshkrimi:",
@@ -38,6 +39,7 @@ OC.L10N.register(
     "Settings & import" : "Konfigurimet dhe importi",
     "Location" : "Vendndodhje",
     "Description" : "Përshkrim",
+    "Duration" : "Kohëzgjatja",
     "to" : "te",
     "Add" : "Shto",
     "Monday" : "E hënë",
@@ -52,6 +54,7 @@ OC.L10N.register(
     "Your email address" : "Adresa juaj email",
     "Notification" : "Njoftim",
     "Email" : "Emaili",
+    "Available" : "i disponueshëm",
     "Unknown" : "I/E panjohur",
     "Accept" : "Prano",
     "Decline" : "Refuzo",
@@ -81,6 +84,7 @@ OC.L10N.register(
     "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
     "Status" : "Status",
     "Confirmed" : "E konfirmuar",
+    "Canceled" : "Anuluar",
     "Categories" : "Kategoritë",
     "Presentation" : "Paraqitje",
     "Office" : "Zyrë",
